package demo


class CustomerService {

    private static TEST_DATA = [
            "Gabrielle Patel", "Brian Robinson", "Eduardo Haugen",
            "Koen Johansen", "Alejandro Macdonald", "Angel Karlsson", "Yahir Gustavsson", "Haiden Svensson",
            "Emily Stewart", "Corinne Davis", "Ryann Davis", "Yurem Jackson", "Kelly Gustavsson",
            "Eileen Walker", "Katelyn Martin", "Israel Carlsson", "Quinn Hansson", "Makena Smith",
            "Danielle Watson", "Leland Harris", "Gunner Karlsen", "Jamar Olsson", "Lara Martin",
            "Ann Andersson", "Remington Andersson", "Rene Carlsson", "Elvis Olsen", "Solomon Olsen",
            "Jaydan Jackson", "Bernard Nilsen"
    ]

    /**
     * retrieves customers and filters
     * @param filter optional, to be contained in customer.toString(), case ignored
     * @return customers matched - or all
     */
    List<Customer> findAll(String filter=null) {
        List<Customer> rtn = Customer.findAll()
        if (filter) {
            filter = filter.toLowerCase()
            rtn = rtn.findAll {Customer cust -> cust.toString().toLowerCase().contains(filter)}
        }
        rtn.sort()
    }

    /**
     * called by BootStrap
     * @param log
     */
    public static void createTestCustomers(log) {
        log.trace "storing customer data:"
        listTestCustomers().each { Customer c ->
            log.trace " '${c}'"
            c.save()
        }
    }
    private static List<Customer> listTestCustomers() {
        List<Customer> rtn = []
        Random r = new Random(0);
        for (String name : TEST_DATA) {
            String[] split = name.split(" ")
            Customer c = new Customer()
            c.firstName = split[0]
            c.lastName = split[1]
            c.email = split[0].toLowerCase() + "@" + split[1].toLowerCase() + ".com"
            c.status = CustomerStatus.values()[r.nextInt(CustomerStatus.values().length)]
            Calendar cal = Calendar.getInstance()
            int daysOld = 0 - r.nextInt(365 * 15 + 365 * 60)
            cal.add(Calendar.DAY_OF_MONTH, daysOld)
            c.birthDate = cal.getTime()
            rtn << c
        }
        rtn
    }



}
