package demo

import com.vaadin.annotations.Theme
import com.vaadin.ui.UI
import com.vaadin.ui.VerticalLayout
import com.vaadin.server.VaadinRequest
import com.vaadin.ui.Label
import com.vaadin.grails.Grails
import com.vaadin.annotations.Theme
import com.vaadin.data.util.BeanItemContainer
import com.vaadin.server.FontAwesome
import com.vaadin.ui.Button
import com.vaadin.ui.CssLayout
import com.vaadin.ui.Grid
import com.vaadin.ui.HorizontalLayout
import com.vaadin.ui.TextField
import com.vaadin.ui.UI
import com.vaadin.ui.VerticalLayout
import com.vaadin.server.VaadinRequest
import com.vaadin.ui.themes.ValoTheme
import org.apache.commons.logging.Log
import org.apache.commons.logging.LogFactory

@Theme('mytheme')
class MyUI extends UI {

    Grid grid
    CustomerService customerService
    TextField filterText
    CustomerForm form
    Log log


    @Override
    protected void init(VaadinRequest vaadinRequest) {
        log = LogFactory.getLog(getClass())
        log.info "MyUI started..."
        grid = new Grid()
        customerService = Grails.get('customerService')    // get Spring bean
        filterText = new TextField()
        form = new CustomerForm(this)
        form.visible = false
        VerticalLayout layout = new VerticalLayout()

        filterText.setInputPrompt("filter by name...")
        filterText.addTextChangeListener { evt -> grid.containerDataSource =
                new BeanItemContainer<Customer>(Customer.class, customerService.findAll(evt.text) )
        }

        Button clearFilterTextBtn = new Button(FontAwesome.TIMES)
        clearFilterTextBtn.description = "Clear the current filter"
        clearFilterTextBtn.addClickListener { evt ->
            filterText.clear()
            updateList()
        }

        CssLayout filtering = new CssLayout()
        filtering.addComponents(filterText, clearFilterTextBtn)
        filtering.styleName = ValoTheme.LAYOUT_COMPONENT_GROUP

        Button addCustomerBtn = new Button("Add new customer");
        addCustomerBtn.addClickListener { evt ->
            grid.select(null)
            form.customer = new Customer()
        }

        HorizontalLayout toolbar = new HorizontalLayout(filtering, addCustomerBtn)
        toolbar.spacing = true


        grid.setColumns('firstName', 'lastName', 'email', 'status')

        HorizontalLayout main = new HorizontalLayout(grid, form)
        main.spacing = true
        main.setSizeFull()
        grid.setSizeFull()
        main.setExpandRatio(grid,1)
        layout.addComponents(toolbar, main)

        updateList()
        layout.margin = true
        content = layout

        grid.addSelectionListener { evt ->
            if (evt.selected.empty) {
                form.visible = false
            } else {
                Customer customer = (Customer) evt.selected.iterator().next()
                form.customer = customer
            }
        }
        log.trace "reached end of MyUI.init()"
    }

    public void updateList() {
        List<Customer> customers = customerService.findAll(filterText.value)
        grid.setContainerDataSource(new BeanItemContainer<>(Customer.class, customers))
    }




}
